// fonts.c

#include <windows.h>
#include <fcntl.h>
#include <io.h>
#include "fonts.h"

LPSTR FontNameFromFile(LPCSTR pszFile)
{
	static char			lpszLongName[256];
	unsigned            i;
	char				namebuf[255];
	int                 fp;
	unsigned short      numNames;
	long				curseek;
	unsigned            cTables;
	sfnt_OffsetTable    OffsetTable;
	sfnt_DirectoryEntry Table;
	sfnt_NamingTable    NamingTable;
	sfnt_NameRecord     NameRecord;

	lpszLongName[0] = '\0';
	if ((fp = open (pszFile, O_RDONLY | O_BINARY)) == -1)
		return NULL;

	/* First off, read the initial directory header on the TTF.  We're only
	* interested in the "numOffsets" variable to tell us how many tables
	* are present in this file.  
	*
	* Remember to always convert from Motorola format (Big Endian to 
	* Little Endian).
	*/
	read (fp, &OffsetTable, sizeof (OffsetTable) - sizeof (sfnt_DirectoryEntry));
	cTables = (int) SWAPW (OffsetTable.numOffsets);

	for ( i = 0; i < cTables && i < 40; i++) {
		if ((read (fp, &Table, sizeof (Table))) != sizeof(Table)) 
			return NULL;
		if (Table.tag == tag_NamingTable) {	/* defined in sfnt_en.h */
			/* Now that we've found the entry for the name table, seek to that
			 * position in the file and read in the initial header for this
			 * particular table.  See "True Type Font Files" for information
			 * on this record layout.
			 */
			lseek (fp, SWAPL (Table.offset), SEEK_SET);
			read (fp, &NamingTable, sizeof (NamingTable));
			numNames = SWAPW(NamingTable.count);
			while (numNames--) {
				read (fp, &NameRecord, sizeof (NameRecord));
				curseek = tell(fp);
				if (SWAPW(NameRecord.platformID) == 1 &&
						SWAPW(NameRecord.nameID) == 4) {
					lseek (fp, SWAPW (NameRecord.offset) + 
						SWAPW(NamingTable.stringOffset) + 
						SWAPL(Table.offset), SEEK_SET);
					read (fp, &namebuf, SWAPW(NameRecord.length));
					namebuf[SWAPW(NameRecord.length)] = '\0';
					lstrcpy(lpszLongName,namebuf);
					lseek (fp, curseek, SEEK_SET);
				}
			}
			close (fp);
			return lpszLongName;
		}
	}
	close (fp);
	return NULL;
}
