///////////////////////////////////////////////////////////////
//
// Font Installation Routines
// Troy Engel <tengel@palladium.net>
//
// Started: 8 Jan 1996
// Last Revised: 27 Oct 1998
// Version: 1.03
// 2000-04-08: added cdecl for IS6 compatibility
//
///////////////////////////////////////////////////////////////

#ifndef _TEFONTS_H_
#define _TEFONTS_H_

#if _ISCRIPT_VER < 0x600
	#define cdecl
#endif

// Our messages
// XX indicates where language identifier goes
// XX_FONT_ASK_INDIV: Used if a BOOL flag is passed asking for individual font confirmation
// XX_FONT_DLG_TITLE: Dialog title(s)
// XX_FONT_GOADD:     Used if user chooses to not install a font when (if) asked
// XX_FONT_NOADD:     A problem was encountered somewhere
// XX_FONT_NOCOPY:    Couldn't copy the TTF file
// XX_FONT_NORES:     Couldn't create the resource (fnt)

// English: Troy Engel <tengel@palladium.net>
#define EN_FONT_ASK_INDIV "The %s font should be installed on your system and has been included with this installation program.\n\nWould you like Setup to install this font for you?"
#define EN_FONT_DLG_TITLE "Font Installation"
#define EN_FONT_GOADD     "The %s font should be installed for best performance of this program.\n\nPlease install the font %s.ttf font manually after Setup has completed."
#define EN_FONT_NOADD     "Setup could not properly add the %s font to your system.\n\nA reboot of your computer will be required for proper operation."
#define EN_FONT_NOCOPY    "Setup could not copy %s.ttf to the system font directory.\n\nPlease install the %s font manually and reboot your computer."
#define EN_FONT_NORES     "Setup could not create a scalable font resource for %s.ttf.\n\nPlease install the %s font manually and reboot your computer."

// German: Stefan Krger <skrueger@installsite.org>
#define DE_FONT_ASK_INDIV "Die Schriftart %s ist in diesem Setup enthalten und soll auf Ihrem Computer installiert werden.\n\nWollen Sie diese Schriftart jetzt installieren?"
#define DE_FONT_DLG_TITLE "Schriftart hinzufgen"
#define DE_FONT_GOADD     "Die Schriftart %s wird bentigt, damit dieses Programm optimal arbeitet.\n\nBitte installieren Sie die Schriftart %s.ttf selbst, nachdem dieses Setup abgeschlossen ist."
#define DE_FONT_NOADD     "Setup konnte die Schriftart %s nicht erfolgreich hinzufgen.\n\nSie mssen Ihrem Computer neu starten, damit dieses Programm korrekt funktioniert."
#define DE_FONT_NOCOPY    "Setup konnte die Datei %s.ttf nicht in das Schriftarten-Verzeichnis kopieren.\n\nBitte installieren Sie die Schriftart %s manuell und starten Sie Ihren Computer neu."
#define DE_FONT_NORES     "Setup konnte keine skalierbare Zeichensatzdatei fr %s.ttf erstellen.\n\nBitte installieren Sie die Schriftart %s manuell und starten Sie Ihren Computer neu."

// French: Dominique Blanchard
#define FR_FONT_ASK_INDIV "Les polices %s devraient tre installes dans votre systme et sont incluses avec ce logiciel d' installation.\n\nDsirez-vous que l'installation procde pour cette police?"
#define FR_FONT_DLG_TITLE "Installation des polices"
#define FR_FONT_GOADD     "Les polices %s doivent tre installes afin d'optimiser la performance de ce logiciel.\n\nVeuillez installer les polices %s.ttf manuellement lorsque l'installation est complte."
#define FR_FONT_NOADD     "L'installation ne peut ajouter les %s polices correctement  votre systme.\n\nVous devez redmarrer votre ordinateur afin d'assurer son opration adquate."
#define FR_FONT_NOCOPY    "L'installation ne peut pas copier les polices %s.ttf  votre rpertoire de polices.\n\nVeuillez installer les polices %s manuellement et redmarrer votre ordinateur."
#define FR_FONT_NORES     "L'installation ne peut crer une ressource  l'chelle pour les polices %s.ttf.\n\nVeuillez installer les polices %s manuellement et redmarrer votre ordinateur."


// Needed for immediate font usage
#define HWND_BROADCAST          0xffff
#define WM_FONTCHANGE           0x001D

// DLL prototypes

// Creates the font resource after copied, used internally
prototype INT GDI.CreateScalableFontResource (INT, BYREF STRING,
                                              BYREF STRING,
                                              STRING);

// Adds the new font availability, used internally
prototype INT GDI.AddFontResource (BYREF STRING);

// Attempts to read the internal font name, used internally
prototype cdecl BOOL tefonts.ReadFontName(BYREF STRING, BYREF STRING,
				BYREF STRING, BYREF STRING);

// Local prototypes

// Inits the languages et al, called by SetupFont (or call it yourself, whatever)
prototype InitFontData();

// Installs a given font
// Params:   param1 = physical name
//           param2 = English name
//           param3 = fullpath to our TTF
//           param4 = ask each font individually
prototype SetupFont(STRING, STRING, STRING, BOOL);

// Counts .TTF files in a directory
// Params:   param1 = Directory
prototype CountTTF(STRING);

// Fills global stringlist with fonts from a directory
// Params:   param1 = Directory
prototype FillFontList(STRING);

// Installs fonts in global fontlist
// Params:   param1 = Directory
prototype InstallFontList(STRING);

// Installs all fonts in a directory
// Params:   param1 = Directory
prototype InstallFontsFromDirectory(STRING);

// Global variables
LIST	FontList;
STRING	szFAskIndiv, szFDlgTitle, szFGoAdd, szFNoAdd, szFNoCopy, szFNoRes;
STRING  szDataInit;

#endif // _TEFONTS_H_
